==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/user/messages/fi/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => '<strong>Käyttäjätilin</strong> luominen',
    '<strong>Change</strong> your password' => '<strong>Vaihda</strong> salasanasi',
    '<strong>Join</strong> the network' => '<strong>Liity</strong>',
    '<strong>Password</strong> changed!' => '<strong>Salasana</strong> vahdettu!',
    '<strong>Password</strong> recovery' => '<strong>Palauta</strong> salasana',
    '<strong>Password</strong> recovery!' => '<strong>Salasanan</strong> palauttaminen!',
    '<strong>Please</strong> sign in' => '<strong>Kirjaudu sisään</strong>',
    '<strong>Registration</strong> successful!' => '<strong>Rekisteröityminen</strong> onnistui!',
    '<strong>Sign</strong> up' => '<strong>Rekisteröidy</strong>',
    '<strong>Your account</strong> has been successfully created!' => '<strong>Käyttäjä</strong> on luotu!',
    'Account' => 'Käyttäjä',
    'After activating your account by the administrator, you will receive a notification by email.' => 'Kun ylläpitäjä on vahvistanut tilisi, saat ilmoituksen sähköpostitse.',
    'Back' => 'Takaisin',
    'Change password' => 'Vaihda salasanasi',
    'Confirm' => 'Vahvista',
    'Create Account' => 'Luo Käyttäjä',
    'Create account' => 'Luo käyttäjä',
    'Don\'t have an account? Join the network by entering your e-mail address.' => 'Liity palveluun antamalla sähköpostiosoitteesi.',
    'Enter security code above' => 'Syötä suojakoodisi ylös',
    'Forgot your password?' => 'Unohditko salasanasi?',
    'Go to login page' => 'Siirry kirjautumissivulle',
    'Group' => 'Ryhmä',
    'Hello {displayName}' => 'Hei {displayName}',
    'Hello {displayName},' => 'Hei {displayName}',
    'If you don\'t use this link within 24 hours, it will expire.' => 'Jos et käytä tätä linkkiä 24 tunnin kuluessa, se lakkaa toimimasta.',
    'If you\'re already a member, please login with your username/email and password.' => 'Jos olet jäsen syötä kirjautumistietosi alle.',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Syötä vain sähköpostiosoitteesi. Lähetämme sinulle palautusohjeet!',
    'Login' => 'Kirjaudu sisään',
    'New user needs approval' => 'Uusi käyttäjä lähetti liitymis pyynnön',
    'Password' => 'Salasana',
    'Password recovery' => 'Salasanan palautus',
    'Password reset' => 'Salasanan palauttaminen',
    'Please check your email and follow the instructions!' => 'Tarkista sähköpostiosoitteesi ja noudata ohjeita!',
    'Please click on the link below to view request:' => 'Klikkaa alla olevaa linkkiä nähdäksesi pyyntö:',
    'Please enter the letters from the image.' => 'Syötä kuvan kirjaimet.',
    'Please login with your username/email and password.' => 'Kirjaudu sisään.',
    'Please use the following link within the next day to reset your password.' => 'Käytä seuraavan linkin salasanan nollaamiseksi.',
    'Register' => 'Rekisteröidy',
    'Registration successful' => 'Rekisteröityminen onnistui',
    'Remember me' => 'Muista minut',
    'Reset Password' => 'Palauta salasana',
    'Reset password' => 'Palauta salasana',
    'Sign in' => 'Kirjaudu sisään',
    'To log in with your new account, click the button below.' => 'Kirjaudu sisään uuden tilin avulla napsauttamalla alla olevaa painiketta.',
    'Username or Email' => 'Sähköposti tai Käyttäjätunnus',
    'Your email' => 'Sähköpostisi',
    'Your password' => 'Salasana',
    'Your password has been successfully changed!' => 'Salasanasi on onnistuneesti vaihdettu!',
    'Your password is incorrect!' => 'Salasana väärin!',
    'a new user {displayName} needs approval.' => 'käyttäjä {displayName} lähetti liittymis pyynnön',
    'back to home' => 'takaisin kotiin',
    '<strong>Change</strong> Password' => '',
    'Due to security reasons you are required to change your password in order to access the platform.' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'Log out' => '',
    'Please wait' => '',
    'User or Password incorrect.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/fi/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => '<strong>Käyttäjätilin</strong> luominen',
    '<strong>Change</strong> your password' => '<strong>Vaihda</strong> salasanasi',
    '<strong>Join</strong> the network' => '<strong>Liity</strong>',
    '<strong>Password</strong> changed!' => '<strong>Salasana</strong> vahdettu!',
    '<strong>Password</strong> recovery' => '<strong>Palauta</strong> salasana',
    '<strong>Password</strong> recovery!' => '<strong>Salasanan</strong> palauttaminen!',
    '<strong>Please</strong> sign in' => '<strong>Kirjaudu sisään</strong>',
    '<strong>Registration</strong> successful!' => '<strong>Rekisteröityminen</strong> onnistui!',
    '<strong>Sign</strong> up' => '<strong>Rekisteröidy</strong>',
    '<strong>Your account</strong> has been successfully created!' => '<strong>Käyttäjä</strong> on luotu!',
    'Account' => 'Käyttäjä',
    'After activating your account by the administrator, you will receive a notification by email.' => 'Kun ylläpitäjä on vahvistanut tilisi, saat ilmoituksen sähköpostitse.',
    'Back' => 'Takaisin',
    'Change password' => 'Vaihda salasanasi',
    'Confirm' => 'Vahvista',
    'Create Account' => 'Luo Käyttäjä',
    'Create account' => 'Luo käyttäjä',
    'Don\'t have an account? Join the network by entering your e-mail address.' => 'Liity palveluun antamalla sähköpostiosoitteesi.',
    'Forgot your password?' => 'Unohditko salasanasi?',
    'Go to login page' => 'Siirry kirjautumissivulle',
    'Group' => 'Ryhmä',
    'Hello {displayName}' => 'Hei {displayName}',
    'Hello {displayName},' => 'Hei {displayName}',
    'If you don\'t use this link within 24 hours, it will expire.' => 'Jos et käytä tätä linkkiä 24 tunnin kuluessa, se lakkaa toimimasta.',
    'If you\'re already a member, please login with your username/email and password.' => 'Jos olet jäsen syötä kirjautumistietosi alle.',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Syötä vain sähköpostiosoitteesi. Lähetämme sinulle palautusohjeet!',
    'Login' => 'Kirjaudu sisään',
    'New user needs approval' => 'Uusi käyttäjä lähetti liitymis pyynnön',
    'Password' => 'Salasana',
    'Password recovery' => 'Salasanan palautus',
    'Password reset' => 'Salasanan palauttaminen',
    'Please click on the link below to view request:' => 'Klikkaa alla olevaa linkkiä nähdäksesi pyyntö:',
    'Please login with your username/email and password.' => 'Kirjaudu sisään.',
    'Please use the following link within the next day to reset your password.' => 'Käytä seuraavan linkin salasanan nollaamiseksi.',
    'Register' => 'Rekisteröidy',
    'Remember me' => 'Muista minut',
    'Reset Password' => 'Palauta salasana',
    'Reset password' => 'Palauta salasana',
    'Sign in' => 'Kirjaudu sisään',
    'To log in with your new account, click the button below.' => 'Kirjaudu sisään uuden tilin avulla napsauttamalla alla olevaa painiketta.',
    'Username or Email' => 'Sähköposti tai Käyttäjätunnus',
    'Your email' => 'Sähköpostisi',
    'Your password' => 'Salasana',
    'Your password has been successfully changed!' => 'Salasanasi on onnistuneesti vaihdettu!',
    'Your password is incorrect!' => 'Salasana väärin!',
    'a new user {displayName} needs approval.' => 'käyttäjä {displayName} lähetti liittymis pyynnön',
    '<strong>Change</strong> Password' => '',
    'Almost there!' => '',
    'An email has been sent to {emailAddress}. Please check your inbox to complete the registration.' => '',
    'Due to security reasons you are required to change your password in order to access the platform.' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'If you don\'t see the email, please check your spam folder.' => '',
    'Log out' => '',
    'Please wait' => '',
    'User or Password incorrect.' => '',
];
